@@ -22,10 +22,10 @@
 namespace KStandardShortcut
 {
 struct KStandardShortcutInfo {
-    //! The standard shortcut id. @see StandardShortcut
+    // The standard shortcut id. @see StandardShortcut
     StandardShortcut id;
 
-    /**
+    /*
      * Unique name for the given accel. The name is used to save the user
      * settings. It's not representable. Use description for that.
      * @warning NEVER EVER CHANGE IT OR TRANSLATE IT!
@@ -38,13 +38,13 @@ struct KStandardShortcutInfo {
         const char *context;
     } description;
 
-    //! The keys for this shortcut
+    // The keys for this shortcut
     int cutDefault, cutDefault2;
 
-    //! A shortcut that is created with @a cutDefault and @cutDefault2
+    // A shortcut that is created with @a cutDefault and @cutDefault2
     QList<QKeySequence> cut;
 
-    //! If this struct is initialized. If not initialized @cut is not valid
+    // If this struct is initialized. If not initialized @cut is not valid
     bool isInitialized;
 
     // Category of this Shortcut
@@ -57,13 +57,15 @@ struct KStandardShortcutInfo {
 #define CTRLSHIFT(x) QKeyCombination(Qt::CTRL | Qt::SHIFT | Qt::Key_##x).toCombined()
 #define ALT(x) QKeyCombination(Qt::ALT | Qt::Key_##x).toCombined()
 #define ALTSHIFT(x) QKeyCombination(Qt::ALT | Qt::SHIFT | Qt::Key_##x).toCombined()
+#define CTRLMETA(x) QKeyCombination(Qt::CTRL | Qt::META | Qt::Key_##x).toCombined()
 
-/** Array of predefined KStandardShortcutInfo objects, which cover all
+/* Array of predefined KStandardShortcutInfo objects, which cover all
     the "standard" accelerators. Each enum value from StandardShortcut
     should appear in this table.
 */
 // STUFF WILL BREAK IF YOU DON'T READ THIS!!!
 // Read the comments of the big enum in kstandardshortcut.h before you change anything!
+// clazy:exclude-next-line=non-pod-global-static
 static KStandardShortcutInfo g_infoStandardShortcut[] = {
     // Group File,
     {AccelNone, nullptr, {nullptr, nullptr}, 0, 0, QList<QKeySequence>(), false, Category::InvalidCategory},
@@ -96,7 +98,11 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
     {DeleteWordBack,
      "DeleteWordBack",
      QT_TRANSLATE_NOOP3("KStandardShortcut", "Delete Word Backwards", "@action"),
+#if defined(Q_OS_MACOS)
+     ALT(Backspace),
+#else
      CTRL(Backspace),
+#endif
      0,
      QList<QKeySequence>(),
      false,
@@ -104,7 +110,11 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
     {DeleteWordForward,
      "DeleteWordForward",
      QT_TRANSLATE_NOOP3("KStandardShortcut", "Delete Word Forward", "@action"),
+#if defined(Q_OS_MACOS)
+     ALT(Delete),
+#else
      CTRL(Delete),
+#endif
      0,
      QList<QKeySequence>(),
      false,
@@ -127,12 +137,27 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
     {Begin,
      "Begin",
      QT_TRANSLATE_NOOP3("KStandardShortcut", "Begin", "@action Beginning of document"),
+#if defined(Q_OS_MACOS)
+     CTRL(Up),
+#else
      CTRL(Home),
+#endif
+     0,
+     QList<QKeySequence>(),
+     false,
+     Category::Navigation},
+    {End,
+     "End",
+     QT_TRANSLATE_NOOP3("KStandardShortcut", "End", "@action End of document"),
+#if defined(Q_OS_MACOS)
+     CTRL(Down),
+#else
+     CTRL(End),
+#endif
      0,
      QList<QKeySequence>(),
      false,
      Category::Navigation},
-    {End, "End", QT_TRANSLATE_NOOP3("KStandardShortcut", "End", "@action End of document"), CTRL(End), 0, QList<QKeySequence>(), false, Category::Navigation},
     {Prior, "Prior", QT_TRANSLATE_NOOP3("KStandardShortcut", "Prior", "@action"), Qt::Key_PageUp, 0, QList<QKeySequence>(), false, Category::Navigation},
     {Next,
      "Next",
@@ -165,7 +190,11 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
     {BeginningOfLine,
      "BeginningOfLine",
      QT_TRANSLATE_NOOP3("KStandardShortcut", "Beginning of Line", "@action"),
+#if defined(Q_OS_MACOS)
+     CTRL(Left),
+#else
      Qt::Key_Home,
+#endif
      0,
      QList<QKeySequence>(),
      false,
@@ -173,7 +202,11 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
     {EndOfLine,
      "EndOfLine",
      QT_TRANSLATE_NOOP3("KStandardShortcut", "End of Line", "@action"),
+#if defined(Q_OS_MACOS)
+     CTRL(Right),
+#else
      Qt::Key_End,
+#endif
      0,
      QList<QKeySequence>(),
      false,
@@ -182,7 +215,11 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
     {BackwardWord,
      "BackwardWord",
      QT_TRANSLATE_NOOP3("KStandardShortcut", "Backward Word", "@action"),
+#if defined(Q_OS_MACOS)
+     ALT(Left),
+#else
      CTRL(Left),
+#endif
      0,
      QList<QKeySequence>(),
      false,
@@ -190,7 +227,11 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
     {ForwardWord,
      "ForwardWord",
      QT_TRANSLATE_NOOP3("KStandardShortcut", "Forward Word", "@action"),
+#if defined(Q_OS_MACOS)
+     ALT(Right),
+#else
      CTRL(Right),
+#endif
      0,
      QList<QKeySequence>(),
      false,
@@ -209,7 +250,11 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
     {FullScreen,
      "FullScreen",
      QT_TRANSLATE_NOOP3("KStandardShortcut", "Full Screen Mode", "@action"),
+#if defined(Q_OS_MACOS)
+     CTRLMETA(F),
+#else
      CTRLSHIFT(F),
+#endif
      0,
      QList<QKeySequence>(),
      false,
@@ -427,7 +472,7 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
     // dummy entry to catch simple off-by-one errors. Insert new entries before this line.
     {AccelNone, nullptr, {nullptr, nullptr}, 0, 0, QList<QKeySequence>(), false, Category::InvalidCategory}};
 
-/** Search for the KStandardShortcutInfo object associated with the given @p id.
+/* Search for the KStandardShortcutInfo object associated with the given @p id.
     Return a dummy entry with no name and an empty shortcut if @p id is invalid.
 */
 static KStandardShortcutInfo *guardedStandardShortcutInfo(StandardShortcut id)
@@ -457,7 +502,7 @@ static void sanitizeShortcutList(QList<QKeySequence> *list)
     }
 }
 
-/** Initialize the accelerator @p id by checking if it is overridden
+/* Initialize the accelerator @p id by checking if it is overridden
     in the configuration file (and if it isn't, use the default).
     On X11, if QApplication was initialized with GUI disabled,
     the default will always be used.
